# OPS01-BP03: Đánh giá các yêu cầu quản trị

## Mô tả

Hiểu các hướng dẫn quản trị (governance guidelines) và nghĩa vụ (obligations) của tổ chức.

## Hướng dẫn triển khai

- Tài liệu hóa các chính sách quản trị của tổ chức
- Xác định các kiểm soát nội bộ áp dụng
- Ánh xạ yêu cầu quản trị sang các biện pháp kiểm soát kỹ thuật
- Thiết lập quy trình rà soát quản trị
- Kiểm toán tuân thủ quản trị định kỳ

## Mức độ rủi ro

Cao - Các lỗi quản trị có thể dẫn đến các hình phạt của tổ chức.

## Các thực hành tốt liên quan

- [OPS01-BP04](OPS01-BP04-Evaluate-Compliance-Requirements.md)
- [SEC01-BP01](../../02-SEC/SEC01-Security-Secure-Operations/SEC01-BP01-Separate-Workloads-Using-Accounts.md)
